==> nextcloud-app-notes-4.7.2-1-any.pkg.tar.xz: usr/share/webapps/nextcloud/apps/notes/l10n/sv.js <==
OC.L10N.register(
    "notes",
    {
    "Notes" : "Anteckningar",
    "Reading notes from filesystem has failed." : "Läsa anteckningar från filsystemet misslyckades.",
    "Error" : "Fel",
    "New note" : "Ny anteckning",
    "Distraction-free notes and writing" : "Distraktionsfria anteckningar och skrivning",
    "Help" : "Hjälp",
    "Please see Nextcloud server log for details." : "Se Nextcloud serverlogg för mer information.",
    "Deleted {title}" : "Raderad {title}",
    "Undo Delete" : "Ångra radering",
    "Note recovered" : "Anteckning återskapad",
    "There are unsaved notes. Leaving the page will discard all changes!" : "Det finns osparade anteckningar. Lämnas sidan kommer ändringarna förloras!",
    "_Deleted {number} note_::_Deleted {number} notes_" : ["Tog bort {number} anteckning","Tog bort {number} anteckningar"],
    "_Recovered {number} note_::_Recovered {number} notes_" : ["Återskapade {number} anteckning","Återskapade {number} anteckningar"],
    "Write down your thoughts without any distractions." : "Skriv ner dina tankar utan några distraktioner.",
    "Organize your notes in categories." : "Organisera dina anteckningar i kategorier.",
    "Use Markdown markups to style your text." : "Använd Markdown för att formatera din text.",
    "Result" : "Resultat",
    "Shortcuts" : "Genvägar",
    "Action" : "Action",
    "Insert image" : "Infoga bild",
    "Start writing a note by clicking on “{newnote}” in the app navigation." : "Böja skriva en anteckning genom att klicka på “{newnote}” i menyn.",
    "Folder to store your notes" : "Mapp för att spara dina anteckningar",
    "File extension for new notes" : "Filtillägg för nya anteckningar",
    "Display mode for notes" : "Visningsläge för anteckningar",
    "Open in edit mode" : "Öppna i redigeringsläge",
    "Open in preview mode" : "Öppna i granskningsläge",
    "No notes yet" : "Inga anteckningar än",
    "Install the app for your mobile phone in order to access your notes from everywhere." : "Installera appen för din mobiltelefon för att få åtkomst till dina anteckningar överallt.",
    "All notes" : "Alla anteckningar",
    "Categories" : "Kategorier",
    "Loading …" : "Läser in ...",
    "Today" : "Idag",
    "Yesterday" : "Igår",
    "This week" : "Denna vecka",
    "Last week" : "Förra veckan",
    "This month" : "Denna månad",
    "Last month" : "Förra månaden",
    "Rename" : "Byt namn",
    "Note's title" : "Anteckningens titel",
    "Details" : "Detaljer",
    "Delete note" : "Ta bort anteckning",
    "Remove from favorites" : "Ta bort från favoriter",
    "Add to favorites" : "Lägg till som favorit",
    "Error during preparing note for deletion." : "Fel vid förberedelse av anteckning för radering.",
    "The note has been changed in another session. Please choose which version should be saved." : "Anteckningen har modifierats i en annan session. Vänligen välj vilken version som skall sparas.",
    "Use version from server" : "Använd version från servern",
    "Use current version" : "Använd nuvarande version",
    "Empty note" : "Tom anteckning",
    "Write …" : "Skriv ...",
    "CTRL + /" : "CTRL + /",
    "Edit" : "Redigera",
    "Preview" : "Förhandsvisa",
    "Exit full screen" : "Avsluta fullskärm",
    "Full screen" : "Fullskärm",
    "Note is read-only. You cannot change it." : "Anteckningen är skrivskyddad. Du kan inte ändra den.",
    "Save failed. Click to retry." : "Kunde inte spara. Klicka för att försöka igen.",
    "Update conflict. Click for resolving manually." : "Uppdateringskonflikt. Klicka för att lösa upp manuellt.",
    "Error from Nextcloud server: {msg}" : "Fel från Nextcloud server: {msg}",
    "Category" : "Kategori",
    "Uncategorized" : "Okategoriserad",
    "Set category" : "Ange kategori",
    "Click here to save manually" : "Klicka här för att spara manuellt.",
    "Saving failed!" : "Misslyckades att spara!",
    "Last modified: {date}" : "Senast ändrad: {date}",
    "Note has unsaved changes" : "Note har osparade ändringar",
    "Subcategory" : "Underkategori",
    "_%n word_::_%n words_" : ["%n ord","%n ord"],
    "_%n character_::_%n characters_" : ["%n tecken","%n tecken"],
    "You can create subcategories by using “/” as delimiter between parent category and subcategory, e.g. “{parent}/{sub}”." : "Du kan skapa underkategorier genom att använda “/” som avgränsare mellan överordnad kategori och underkategori, t.ex. “{parent}/{sub}”.",
    "Note not found." : "Anteckningen hittades inte.",
    "Note is locked." : "Anteckningen är låst.",
    "Insufficient storage." : "Otillräckligt utrymme.",
    "See JavaScript console and server log for details." : "Se JavaScript-konsol och serverlogg för detaljer.",
    "Updating settings has failed." : "Kunde inte uppdatera inställningar. ",
    "Fetching notes for dashboard has failed." : "Hämtning av anteckningar för dashboarden misslyckades",
    "Fetching notes has failed." : "Kunde inte hämta anteckningar.",
    "Fetching note {id} has failed." : "Hämtning av anteckning {id} misslyckades.",
    "Refreshing note {id} has failed." : "Uppdatering av anteckning {id} misslyckades.",
    "Renaming note {id} has failed." : "Namnbyte av anteckning {id} misslyckades.",
    "Creating new note has failed." : "Kunde inte skapa ny anteckning.",
    "Saving note {id} has failed." : "Spara anteckning {id} misslyckades.",
    "Updating title for note {id} has failed." : "Uppdatering av titel för anteckning {id} misslyckades.",
    "Undo delete has failed for note {title}." : "Ångra radering misslyckades för anteckning {title}.",
    "Deleting note {id} has failed." : "Radering av anteckning {id} misslyckades.",
    "Toggling favorite for note {id} has failed." : "Växling av favorit för anteckning {id} misslyckades.",
    "Updating the note's category has failed. Is the target directory writable?" : "Uppdatering av anteckningens kategori misslyckades. Är målmappen skrivbar?",
    "Updating the category for note {id} has failed." : "Uppdatering av kategori för anteckning {id} misslyckades.",
    "Tasks" : "Uppgifter",
    "Development Mode" : "Utvecklingsläge",
    "It looks that the notes app was installed from a development source. Please install it from the official <a href=\"%1$s\">Nextcloud App Store</a> instead. If you want to build the Notes app by yourself, please follow the <a href=\"%2$s\">developer instructions</a>." : "Det ser ut som att anteckningsappen installerades från en utvecklingskälla. Installera från den officiella <a href=\"%1$s\">Nextcloud App-Store</a> istället. Om du vill bygga Notes-appen själv, följ <a href=\"%2$s\">utvecklarinstruktionerna</a>."
},
"nplurals=2; plural=(n != 1);");

==> nextcloud-app-notes-4.8.1-1-any.pkg.tar.xz: usr/share/webapps/nextcloud/apps/notes/l10n/sv.js <==
OC.L10N.register(
    "notes",
    {
    "Notes" : "Anteckningar",
    "Create new note" : "Skapa ny anteckning",
    "More notes" : "Fler anteckningar",
    "Reading notes from filesystem has failed." : "Läsa anteckningar från filsystemet misslyckades.",
    "Error" : "Fel",
    "New note" : "Ny anteckning",
    "Distraction-free notes and writing" : "Distraktionsfria anteckningar och skrivning",
    "Notes settings" : "Anteckningsinställningar",
    "Please see Nextcloud server log for details." : "Se Nextcloud serverlogg för mer information.",
    "Deleted {title}" : "Raderad {title}",
    "Undo Delete" : "Ångra radering",
    "Note recovered" : "Anteckning återskapad",
    "There are unsaved notes. Leaving the page will discard all changes!" : "Det finns osparade anteckningar. Lämnas sidan kommer ändringarna förloras!",
    "_Deleted {number} note_::_Deleted {number} notes_" : ["Tog bort {number} anteckning","Tog bort {number} anteckningar"],
    "_Recovered {number} note_::_Recovered {number} notes_" : ["Återskapade {number} anteckning","Återskapade {number} anteckningar"],
    "Basics" : "Grunder",
    "Write down your thoughts without any distractions." : "Skriv ner dina tankar utan några distraktioner.",
    "Organize your notes in categories." : "Organisera dina anteckningar i kategorier.",
    "Notes path" : "Sökväg för anteckningar",
    "Folder to store your notes" : "Mapp för att spara dina anteckningar",
    "Root directory" : "Root-mapp",
    "File extension" : "Filändelse",
    "File extension for new notes" : "Filtillägg för nya anteckningar",
    "Display mode" : "Visningsläge",
    "Display mode for notes" : "Visningsläge för anteckningar",
    "Shortcuts" : "Genvägar",
    "Use shortcuts to quickly navigate this app." : "Använd genvägar för att snabbt navigera i den här appen.",
    "Shortcut" : "Genväg",
    "Action" : "Action",
    "Mobile apps" : "Mobilappar",
    "User defined" : "Användardefinierad",
    "Open in rich text mode" : "Öppna i rich text-läge",
    "Open in edit mode" : "Öppna i redigeringsläge",
    "Open in preview mode" : "Öppna i granskningsläge",
    "CTRL" : "CTRL",
    "Make the selection bold" : "Gör markeringen fetstil",
    "Make the selection italic" : "Gör markeringen kursiv",
    "Wrap the selection in quotes" : "Sätt markeringen inom citattecken",
    "ALT" : "ALT",
    "The selection will be turned into monospace" : "Urvalet kommer att förvandlas till monospace",
    "Remove any styles from the selected text" : "Ta bort all formatering från den markerade texten",
    "Makes the current line a list element" : "Gör den aktuella raden till ett listelement",
    "Makes the current line a list element with a number" : "Gör den aktuella raden till ett listelement med ett nummer",
    "Toggle heading for current line" : "Växla rubrik för aktuell rad",
    "SHIFT" : "SHIFT",
    "Set the current line as a big heading" : "Ställ in den aktuella raden som en stor rubrik",
    "Insert link" : "Infoga länk",
    "Insert image" : "Infoga bild",
    "Switch between editor and viewer" : "Växla mellan redigerare och visare",
    "Select folder to link to" : "Välj mapp att länka till",
    "All notes" : "Alla anteckningar",
    "Categories" : "Kategorier",
    "Create a sample note with Markdown" : "Skapa en exempelanteckning med Markdown",
    "No notes yet" : "Inga anteckningar än",
    "Upload image" : "Ladda upp bild",
    "Select an image" : "Välj en bild",
    "You cannot select images outside of your notes folder. Your notes folder is: {folder}" : "Du kan inte välja bilder utanför din anteckningsmapp. Din anteckningsmapp är: {folder}",
    "Wrong image" : "Fel bild",
    "The file was not uploaded. Check your server logs." : "Filen laddades inte upp. Kontrollera dina serverloggar.",
    "Install the app for your mobile phone in order to access your notes from everywhere." : "Installera appen för din mobiltelefon för att få åtkomst till dina anteckningar överallt.",
    "Android app: {notes}" : "Android-app: {notes}",
    "iOS app: {notes}" : "iOS-app: {notes}",
    "Rich text editor" : "Rich text-editor",
    "You can now switch to use the easy to use and distraction free rich text editor. It allows you to edit notes without seeing any Markdown marks." : "Du kan nu byta till att använda den lättanvända och distraktionsfria textredigeraren. Det låter dig redigera anteckningar utan att se några Markdown-märken.",
    "This option can also be changed later on in the Notes app settings." : "Det här alternativet kan också ändras senare i Notes-appens inställningar.",
    "Keep plain Markdown editor" : "Behåll vanlig Markdown-redigerare",
    "Use rich editor" : "Använd rich text-editor",
    "Details" : "Detaljer",
    "Delete note" : "Ta bort anteckning",
    "Remove from favorites" : "Ta bort från favoriter",
    "Add to favorites" : "Lägg till som favorit",
    "Error during preparing note for deletion." : "Fel vid förberedelse av anteckning för radering.",
    "The note has been changed in another session. Please choose which version should be saved." : "Anteckningen har modifierats i en annan session. Vänligen välj vilken version som skall sparas.",
    "Use version from server" : "Använd version från servern",
    "Use current version" : "Använd nuvarande version",
    "Empty note" : "Tom anteckning",
    "Write …" : "Skriv ...",
    "CTRL + /" : "CTRL + /",
    "Edit" : "Redigera",
    "Preview" : "Förhandsvisa",
    "Exit full screen" : "Avsluta fullskärm",
    "Full screen" : "Fullskärm",
    "Note is read-only. You cannot change it." : "Anteckningen är skrivskyddad. Du kan inte ändra den.",
    "Save failed. Click to retry." : "Kunde inte spara. Klicka för att försöka igen.",
    "Update conflict. Click for resolving manually." : "Uppdateringskonflikt. Klicka för att lösa upp manuellt.",
    "Error from Nextcloud server: {msg}" : "Fel från Nextcloud server: {msg}",
    "Search for notes" : "Sök efter anteckningar",
    "Loading …" : "Läser in ...",
    "Find in all categories" : "Hitta i alla kategorier",
    "Today" : "Idag",
    "Yesterday" : "Igår",
    "This week" : "Denna vecka",
    "Last week" : "Förra veckan",
    "This month" : "Denna månad",
    "Last month" : "Förra månaden",
    "Category" : "Kategori",
    "Uncategorized" : "Okategoriserad",
    "Set category" : "Ange kategori",
    "Click here to save manually" : "Klicka här för att spara manuellt.",
    "Saving failed!" : "Misslyckades att spara!",
    "Last modified: {date}" : "Senast ändrad: {date}",
    "Note has unsaved changes" : "Note har osparade ändringar",
    "Subcategory" : "Underkategori",
    "Click to edit title" : "Klicka för att redigera titel",
    "_%n word_::_%n words_" : ["%n ord","%n ord"],
    "_%n character_::_%n characters_" : ["%n tecken","%n tecken"],
    "Use Markdown markups to style your text." : "Använd Markdown för att formatera din text.",
    "Start writing a note by clicking on “{newnote}” in the app navigation." : "Böja skriva en anteckning genom att klicka på “{newnote}” i menyn.",
    "You can create subcategories by using “/” as delimiter between parent category and subcategory, e.g. “{parent}/{sub}”." : "Du kan skapa underkategorier genom att använda “/” som avgränsare mellan överordnad kategori och underkategori, t.ex. “{parent}/{sub}”.",
    "Note not found." : "Anteckningen hittades inte.",
    "Note is locked." : "Anteckningen är låst.",
    "Insufficient storage." : "Otillräckligt utrymme.",
    "See JavaScript console and server log for details." : "Se JavaScript-konsol och serverlogg för detaljer.",
    "Updating settings has failed." : "Kunde inte uppdatera inställningar. ",
    "Fetching notes for dashboard has failed." : "Hämtning av anteckningar för dashboarden misslyckades",
    "Fetching notes has failed." : "Kunde inte hämta anteckningar.",
    "Fetching note {id} has failed." : "Hämtning av anteckning {id} misslyckades.",
    "Refreshing note {id} has failed." : "Uppdatering av anteckning {id} misslyckades.",
    "Renaming note {id} has failed." : "Namnbyte av anteckning {id} misslyckades.",
    "Creating new note has failed." : "Kunde inte skapa ny anteckning.",
    "Saving note {id} has failed." : "Spara anteckning {id} misslyckades.",
    "Updating title for note {id} has failed." : "Uppdatering av titel för anteckning {id} misslyckades.",
    "Undo delete has failed for note {title}." : "Ångra radering misslyckades för anteckning {title}.",
    "Deleting note {id} has failed." : "Radering av anteckning {id} misslyckades.",
    "Toggling favorite for note {id} has failed." : "Växling av favorit för anteckning {id} misslyckades.",
    "Updating the note's category has failed. Is the target directory writable?" : "Uppdatering av anteckningens kategori misslyckades. Är målmappen skrivbar?",
    "Updating the category for note {id} has failed." : "Uppdatering av kategori för anteckning {id} misslyckades.",
    "Sample note" : "Exempelanteckning",
    "15 January 2021, via Nextcloud Notes" : "15 januari 2021, via Nextcloud Notes",
    "Me, you, and all our friends!" : "Jag, du och alla våra vänner!",
    "Tasks" : "Uppgifter",
    "Write nice todo lists" : "Skriv fina att göra-listor",
    "Buy Fries" : "Köp pommes frites",
    "Birthdays" : "Födelsedagar",
    "Jen, in three days!" : "Jen, om tre dagar!",
    "Moss, 21.03.1973" : "Moss, 21.03.1973",
    "Roy, 1979" : "Roy, 1979",
    "Review Steps" : "Granska steg",
    "Turn PC off" : "Stäng av datorn",
    "Turn PC on" : "Slå på datorn",
    "Then call IT" : "Ring sedan IT",
    "Quotes" : "Citat",
    "Nextcloud, a safe home for all your data" : "Nextcloud, ett säkert hem för all din data",
    "Development Mode" : "Utvecklingsläge",
    "It looks that the notes app was installed from a development source. Please install it from the official <a href=\"%1$s\">Nextcloud App Store</a> instead. If you want to build the Notes app by yourself, please follow the <a href=\"%2$s\">developer instructions</a>." : "Det ser ut som att anteckningsappen installerades från en utvecklingskälla. Installera från den officiella <a href=\"%1$s\">Nextcloud App-Store</a> istället. Om du vill bygga Notes-appen själv, följ <a href=\"%2$s\">utvecklarinstruktionerna</a>."
},
"nplurals=2; plural=(n != 1);");
